package dmoisan.xml.tvschedule;
import java.io.*;
/**
* TVScheduleOutputObject
*	Abstract base class for TVScheduleScalaScript
*	and other objects that generate output from
*
* @author David Moisan
* @version 0.9 3 May 1999
* @see ScalaScript
* @see ProgramItem
*
*/

abstract public class TVScheduleOutputObject {

/**
* 
* newSchedule(String schedulename)
*   Intialize new Scala schedule object 
*
* @param schedulename (String) Name of TV schedule
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void newSchedule(String schedulename) throws TVScheduleParseException, IOException;

/**
* newChannel -- Initialize new channel output object.
*
* @param channel Channel name
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void newChannel(String channel) throws TVScheduleParseException, IOException;
   

/**
* setBanner -- Set banner
*
*
* @param banner String Banner text
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void setBanner(String banner) throws TVScheduleParseException, IOException;

/**
* setHoliday 
*   Get the Holiday text from the parser
*
*
* @param holiday String Holiday notification text
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*/

abstract public void setHoliday(String banner) throws TVScheduleParseException, IOException;

/**
* newProgram -- Insert new program item
*
*
* @param program ProgramItem Program information
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void newProgram(ProgramItem program) throws TVScheduleParseException, IOException;


/**
* startDay -- Start programming day. 
*
*
* @param day String Current programming day
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/
	
abstract public void startDay(String day) throws TVScheduleParseException, IOException;
 
/**
*
* endDay -- End programming day.  Usually used to end the current page.  
*
* @exception TVScheduleParseException  Thrown on parsing/semantic
* errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void endDay() throws TVScheduleParseException, IOException;

/**
* endChannel -- End Channel.
*     Used to close the current output file.
*
* @exception TVScheduleParseException  Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O errors
*
*/

abstract public void endChannel() throws TVScheduleParseException, IOException;

/**
* endSchedule -- Close all files
*
* @exception TVScheduleParseException Thrown on parsing/semantic errors
* @exception IOException Thrown on I/O Errors
*
*/
abstract public void endSchedule() throws TVScheduleParseException, IOException;
     }

